==> mol-1.4.tar.gz: simula+/tests/affiche.h <==
/***************************************************************
 *                    simula+@metz.ensam.fr                    *
 *                   GNU/linux version 0.0.2                   *
 *            software under General Public License            *
 ***************************************************************
 * copyright  2002,2006 COLLARD Christophe
 * copyright  2002,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
 * copyright  2002,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
 ***************************************************************/

/*
    affiche belongs to Mathematical Object Libraries (MOL++)
    MOL++ is part of Simula+

    Simula+ is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Simula+ is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Simula+; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef __cplusplus
#error Must use C++ for affiche.h
#endif

#if !defined(__IOSTREAM_H)
#include <iostream>
#endif

#if !defined(__AFFICHE_H)
#define __AFFICHE_H

using namespace std;

void affiche (char* text, int result)
{
  cout << text;
  if (result) cout << " ok \n";
  else {cout << " error \n"; exit(1);}
}

#endif

==> mol-2.4.tar.gz: simula+/tests/affiche.h <==
/***************************************************************
 *                    simula+@metz.ensam.fr                    *
 *                   GNU/linux version 2.4.0                   *
 *            software under General Public License            *
 ***************************************************************
 * copyright © 2002,2006,2009 COLLARD Christophe
 * copyright © 2002,2006,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
 * copyright © 2002,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
 ***************************************************************/

/*
    affiche belongs to Mathematical Object Libraries (MOL++)
    MOL++ is part of Simula+

    Simula+ is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Simula+ is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Simula+; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef __cplusplus
#error Must use C++ for affiche.h
#endif

#if !defined(__IOSTREAM_H)
#include <iostream>
#endif

#if !defined(__COLORS_H)
#include "colors.h"
#endif

#if !defined(__AFFICHE_H)
#define __AFFICHE_H

using namespace std;

void affiche (char* text, int result)
{
  cout << text << ":";
  if (result) cout << green << " ok" << reset;
  else {cout << red << " error" << reset; exit(1);}
}

#endif
